@@ -1,4 +1,4 @@
-corrected_lasso_gaussian <- function(W, y,sigmaUU, radii, no_radii, alpha, maxits){
+corrected_lasso_gaussian <- function(W, y,sigmaUU, radii, no_radii, alpha, maxits, tol){
 
   # Mean-subtract the columns of W
   W <- scale(W, scale = FALSE)
@@ -24,7 +24,7 @@ corrected_lasso_gaussian <- function(W, y,sigmaUU, radii, no_radii, alpha, maxit
 
   for(r in 2 : (no_radii + 1)) {
     # Compute the estimate
-    betaCorr[, r] <- project_gradient(Q, b, maxits, alpha, radii[r - 1], betaCorr[, r-1])
+    betaCorr[, r] <- project_gradient(Q, b, maxits, alpha, radii[r - 1], betaCorr[, r-1], tol)
   }
 
 
