@@ -36,11 +36,11 @@ plot.corrected_lasso <- function(x, type = "nonzero", label = FALSE, ...) {
       coefficient = 1:length(x$betaCorr),
       estimate = x$betaCorr
     )
-    ggplot2::ggplot(df, ggplot2::aes_(x =~ coefficient, y =~ estimate)) +
+    ggplot2::ggplot(df, ggplot2::aes(x = .data$coefficient, y = .data$estimate)) +
       ggplot2::geom_point()
   } else if(type == "nonzero") {
     df <- data.frame(radius = x$radii, nonZero = colSums(abs(x$betaCorr) > 0))
-    ggplot2::ggplot(df, ggplot2::aes_(x =~ radius, y =~ nonZero)) +
+    ggplot2::ggplot(df, ggplot2::aes(x = .data$radius, y = .data$nonZero)) +
       ggplot2::geom_line() +
       ggplot2::labs(x = "radius", y = "Nonzero coefficients", title = "Number of nonzero coefficients")
   } else if (type == "path") {
@@ -48,7 +48,7 @@ plot.corrected_lasso <- function(x, type = "nonzero", label = FALSE, ...) {
                      coefficient_id = as.factor(rep(seq_along(1:nrow(x$betaCorr)), each = length(x$radii))),
                      beta_corr = as.vector(t(x$betaCorr)))
 
-    p <- ggplot2::ggplot(df, ggplot2::aes_(x =~ radius, y =~ beta_corr, color =~ coefficient_id)) +
+    p <- ggplot2::ggplot(df, ggplot2::aes(x = .data$radius, y = .data$beta_corr, color = .data$coefficient_id)) +
       ggplot2::geom_path() +
       ggplot2::labs(x = "radius", y = "Coefficient estimate", title = "Coefficient paths") +
       ggplot2::theme(legend.position="none")
@@ -56,7 +56,7 @@ plot.corrected_lasso <- function(x, type = "nonzero", label = FALSE, ...) {
     if(label){
       lab_df <- df[df$radius == max(x$radii), ]
       p +
-        ggplot2::geom_label(data = lab_df, ggplot2::aes_(label =~ coefficient_id))
+        ggplot2::geom_label(data = lab_df, ggplot2::aes(label = .data$coefficient_id))
     } else {
       p
     }
