@@ -6,9 +6,9 @@
 plot.cv_corrected_lasso <- function(x, ...) {
 
 
-  ggplot2::ggplot(as.data.frame(x$cv),
-                  ggplot2::aes_(x =~ radii, y =~ mean_loss,
-                                ymin =~ lower_1se, ymax =~ upper_1se)) +
+  ggplot2::ggplot(x$cv,
+                  ggplot2::aes(x = .data$radii, y = .data$mean_loss,
+                                ymin = .data$lower_1se, ymax = .data$upper_1se)) +
     ggplot2::geom_point() +
     ggplot2::geom_errorbar(color = "gray") +
     ggplot2::labs(x = "Radius", y = "Loss", title = "Cross-validation plot for corrected lasso")
